/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/lximage-qt-0.6.0/src/mainwindow.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_LxImage__MainWindow_t {
    QByteArrayData data[40];
    char stringdata0[939];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_LxImage__MainWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_LxImage__MainWindow_t qt_meta_stringdata_LxImage__MainWindow = {
    {
QT_MOC_LITERAL(0, 0, 19), // "LxImage::MainWindow"
QT_MOC_LITERAL(1, 20, 24), // "on_actionAbout_triggered"
QT_MOC_LITERAL(2, 45, 0), // ""
QT_MOC_LITERAL(3, 46, 27), // "on_actionOpenFile_triggered"
QT_MOC_LITERAL(4, 74, 32), // "on_actionOpenDirectory_triggered"
QT_MOC_LITERAL(5, 107, 28), // "on_actionNewWindow_triggered"
QT_MOC_LITERAL(6, 136, 23), // "on_actionSave_triggered"
QT_MOC_LITERAL(7, 160, 25), // "on_actionSaveAs_triggered"
QT_MOC_LITERAL(8, 186, 24), // "on_actionPrint_triggered"
QT_MOC_LITERAL(9, 211, 25), // "on_actionDelete_triggered"
QT_MOC_LITERAL(10, 237, 33), // "on_actionFileProperties_trigg..."
QT_MOC_LITERAL(11, 271, 24), // "on_actionClose_triggered"
QT_MOC_LITERAL(12, 296, 34), // "on_actionRotateClockwise_trig..."
QT_MOC_LITERAL(13, 331, 41), // "on_actionRotateCounterclockwi..."
QT_MOC_LITERAL(14, 373, 31), // "on_actionFlipVertical_triggered"
QT_MOC_LITERAL(15, 405, 33), // "on_actionFlipHorizontal_trigg..."
QT_MOC_LITERAL(16, 439, 23), // "on_actionCopy_triggered"
QT_MOC_LITERAL(17, 463, 24), // "on_actionPaste_triggered"
QT_MOC_LITERAL(18, 488, 25), // "on_actionUpload_triggered"
QT_MOC_LITERAL(19, 514, 33), // "on_actionShowThumbnails_trigg..."
QT_MOC_LITERAL(20, 548, 7), // "checked"
QT_MOC_LITERAL(21, 556, 29), // "on_actionFullScreen_triggered"
QT_MOC_LITERAL(22, 586, 28), // "on_actionSlideShow_triggered"
QT_MOC_LITERAL(23, 615, 27), // "on_actionPrevious_triggered"
QT_MOC_LITERAL(24, 643, 23), // "on_actionNext_triggered"
QT_MOC_LITERAL(25, 667, 24), // "on_actionFirst_triggered"
QT_MOC_LITERAL(26, 692, 23), // "on_actionLast_triggered"
QT_MOC_LITERAL(27, 716, 25), // "on_actionZoomIn_triggered"
QT_MOC_LITERAL(28, 742, 26), // "on_actionZoomOut_triggered"
QT_MOC_LITERAL(29, 769, 31), // "on_actionOriginalSize_triggered"
QT_MOC_LITERAL(30, 801, 26), // "on_actionZoomFit_triggered"
QT_MOC_LITERAL(31, 828, 13), // "onContextMenu"
QT_MOC_LITERAL(32, 842, 3), // "pos"
QT_MOC_LITERAL(33, 846, 16), // "onExitFullscreen"
QT_MOC_LITERAL(34, 863, 21), // "onThumbnailSelChanged"
QT_MOC_LITERAL(35, 885, 14), // "QItemSelection"
QT_MOC_LITERAL(36, 900, 8), // "selected"
QT_MOC_LITERAL(37, 909, 10), // "deselected"
QT_MOC_LITERAL(38, 920, 13), // "onFileDropped"
QT_MOC_LITERAL(39, 934, 4) // "path"

    },
    "LxImage::MainWindow\0on_actionAbout_triggered\0"
    "\0on_actionOpenFile_triggered\0"
    "on_actionOpenDirectory_triggered\0"
    "on_actionNewWindow_triggered\0"
    "on_actionSave_triggered\0"
    "on_actionSaveAs_triggered\0"
    "on_actionPrint_triggered\0"
    "on_actionDelete_triggered\0"
    "on_actionFileProperties_triggered\0"
    "on_actionClose_triggered\0"
    "on_actionRotateClockwise_triggered\0"
    "on_actionRotateCounterclockwise_triggered\0"
    "on_actionFlipVertical_triggered\0"
    "on_actionFlipHorizontal_triggered\0"
    "on_actionCopy_triggered\0"
    "on_actionPaste_triggered\0"
    "on_actionUpload_triggered\0"
    "on_actionShowThumbnails_triggered\0"
    "checked\0on_actionFullScreen_triggered\0"
    "on_actionSlideShow_triggered\0"
    "on_actionPrevious_triggered\0"
    "on_actionNext_triggered\0"
    "on_actionFirst_triggered\0"
    "on_actionLast_triggered\0"
    "on_actionZoomIn_triggered\0"
    "on_actionZoomOut_triggered\0"
    "on_actionOriginalSize_triggered\0"
    "on_actionZoomFit_triggered\0onContextMenu\0"
    "pos\0onExitFullscreen\0onThumbnailSelChanged\0"
    "QItemSelection\0selected\0deselected\0"
    "onFileDropped\0path"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_LxImage__MainWindow[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      32,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,  174,    2, 0x08 /* Private */,
       3,    0,  175,    2, 0x08 /* Private */,
       4,    0,  176,    2, 0x08 /* Private */,
       5,    0,  177,    2, 0x08 /* Private */,
       6,    0,  178,    2, 0x08 /* Private */,
       7,    0,  179,    2, 0x08 /* Private */,
       8,    0,  180,    2, 0x08 /* Private */,
       9,    0,  181,    2, 0x08 /* Private */,
      10,    0,  182,    2, 0x08 /* Private */,
      11,    0,  183,    2, 0x08 /* Private */,
      12,    0,  184,    2, 0x08 /* Private */,
      13,    0,  185,    2, 0x08 /* Private */,
      14,    0,  186,    2, 0x08 /* Private */,
      15,    0,  187,    2, 0x08 /* Private */,
      16,    0,  188,    2, 0x08 /* Private */,
      17,    0,  189,    2, 0x08 /* Private */,
      18,    0,  190,    2, 0x08 /* Private */,
      19,    1,  191,    2, 0x08 /* Private */,
      21,    1,  194,    2, 0x08 /* Private */,
      22,    1,  197,    2, 0x08 /* Private */,
      23,    0,  200,    2, 0x08 /* Private */,
      24,    0,  201,    2, 0x08 /* Private */,
      25,    0,  202,    2, 0x08 /* Private */,
      26,    0,  203,    2, 0x08 /* Private */,
      27,    0,  204,    2, 0x08 /* Private */,
      28,    0,  205,    2, 0x08 /* Private */,
      29,    0,  206,    2, 0x08 /* Private */,
      30,    0,  207,    2, 0x08 /* Private */,
      31,    1,  208,    2, 0x08 /* Private */,
      33,    0,  211,    2, 0x08 /* Private */,
      34,    2,  212,    2, 0x08 /* Private */,
      38,    1,  217,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   20,
    QMetaType::Void, QMetaType::Bool,   20,
    QMetaType::Void, QMetaType::Bool,   20,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QPoint,   32,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 35, 0x80000000 | 35,   36,   37,
    QMetaType::Void, QMetaType::QString,   39,

       0        // eod
};

void LxImage::MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        MainWindow *_t = static_cast<MainWindow *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->on_actionAbout_triggered(); break;
        case 1: _t->on_actionOpenFile_triggered(); break;
        case 2: _t->on_actionOpenDirectory_triggered(); break;
        case 3: _t->on_actionNewWindow_triggered(); break;
        case 4: _t->on_actionSave_triggered(); break;
        case 5: _t->on_actionSaveAs_triggered(); break;
        case 6: _t->on_actionPrint_triggered(); break;
        case 7: _t->on_actionDelete_triggered(); break;
        case 8: _t->on_actionFileProperties_triggered(); break;
        case 9: _t->on_actionClose_triggered(); break;
        case 10: _t->on_actionRotateClockwise_triggered(); break;
        case 11: _t->on_actionRotateCounterclockwise_triggered(); break;
        case 12: _t->on_actionFlipVertical_triggered(); break;
        case 13: _t->on_actionFlipHorizontal_triggered(); break;
        case 14: _t->on_actionCopy_triggered(); break;
        case 15: _t->on_actionPaste_triggered(); break;
        case 16: _t->on_actionUpload_triggered(); break;
        case 17: _t->on_actionShowThumbnails_triggered((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 18: _t->on_actionFullScreen_triggered((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 19: _t->on_actionSlideShow_triggered((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 20: _t->on_actionPrevious_triggered(); break;
        case 21: _t->on_actionNext_triggered(); break;
        case 22: _t->on_actionFirst_triggered(); break;
        case 23: _t->on_actionLast_triggered(); break;
        case 24: _t->on_actionZoomIn_triggered(); break;
        case 25: _t->on_actionZoomOut_triggered(); break;
        case 26: _t->on_actionOriginalSize_triggered(); break;
        case 27: _t->on_actionZoomFit_triggered(); break;
        case 28: _t->onContextMenu((*reinterpret_cast< QPoint(*)>(_a[1]))); break;
        case 29: _t->onExitFullscreen(); break;
        case 30: _t->onThumbnailSelChanged((*reinterpret_cast< const QItemSelection(*)>(_a[1])),(*reinterpret_cast< const QItemSelection(*)>(_a[2]))); break;
        case 31: _t->onFileDropped((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QItemSelection >(); break;
            }
            break;
        }
    }
}

const QMetaObject LxImage::MainWindow::staticMetaObject = {
    { &QMainWindow::staticMetaObject, qt_meta_stringdata_LxImage__MainWindow.data,
      qt_meta_data_LxImage__MainWindow,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *LxImage::MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LxImage::MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_LxImage__MainWindow.stringdata0))
        return static_cast<void*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int LxImage::MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
