/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -a applicationadaptor -c ApplicationAdaptor -i application.h -l LxImage::Application /usr/src/ports/lximage-qt/lximage-qt-0.6.0-1.x86_64/src/lximage-qt-0.6.0/src/org.lxde.LxImage.Application.xml
 *
 * qdbusxml2cpp is Copyright (C) 2017 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "applicationadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class ApplicationAdaptor
 */

ApplicationAdaptor::ApplicationAdaptor(LxImage::Application *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

ApplicationAdaptor::~ApplicationAdaptor()
{
    // destructor
}

void ApplicationAdaptor::newWindow(const QStringList &in0)
{
    // handle method call org.lxde.LxImage.Application.newWindow
    parent()->newWindow(in0);
}

void ApplicationAdaptor::screenshot()
{
    // handle method call org.lxde.LxImage.Application.screenshot
    parent()->screenshot();
}


#include "applicationadaptor.moc"
