/********************************************************************************
** Form generated from reading UI file 'preferencesdialog.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFERENCESDIALOG_H
#define UI_PREFERENCESDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <libfm-qt/colorbutton.h>

QT_BEGIN_NAMESPACE

class Ui_PreferencesDialog
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *tab;
    QFormLayout *formLayout;
    QLabel *iconThemeLabel;
    QComboBox *iconTheme;
    QLabel *label;
    QLabel *label_2;
    Fm::ColorButton *bgColor;
    Fm::ColorButton *fullScreenBgColor;
    QLabel *label_3;
    QSpinBox *slideShowInterval;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *PreferencesDialog)
    {
        if (PreferencesDialog->objectName().isEmpty())
            PreferencesDialog->setObjectName(QStringLiteral("PreferencesDialog"));
        PreferencesDialog->resize(331, 225);
        verticalLayout = new QVBoxLayout(PreferencesDialog);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        tabWidget = new QTabWidget(PreferencesDialog);
        tabWidget->setObjectName(QStringLiteral("tabWidget"));
        tab = new QWidget();
        tab->setObjectName(QStringLiteral("tab"));
        formLayout = new QFormLayout(tab);
        formLayout->setObjectName(QStringLiteral("formLayout"));
        formLayout->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        iconThemeLabel = new QLabel(tab);
        iconThemeLabel->setObjectName(QStringLiteral("iconThemeLabel"));

        formLayout->setWidget(0, QFormLayout::LabelRole, iconThemeLabel);

        iconTheme = new QComboBox(tab);
        iconTheme->setObjectName(QStringLiteral("iconTheme"));

        formLayout->setWidget(0, QFormLayout::FieldRole, iconTheme);

        label = new QLabel(tab);
        label->setObjectName(QStringLiteral("label"));

        formLayout->setWidget(1, QFormLayout::LabelRole, label);

        label_2 = new QLabel(tab);
        label_2->setObjectName(QStringLiteral("label_2"));

        formLayout->setWidget(2, QFormLayout::LabelRole, label_2);

        bgColor = new Fm::ColorButton(tab);
        bgColor->setObjectName(QStringLiteral("bgColor"));

        formLayout->setWidget(1, QFormLayout::FieldRole, bgColor);

        fullScreenBgColor = new Fm::ColorButton(tab);
        fullScreenBgColor->setObjectName(QStringLiteral("fullScreenBgColor"));

        formLayout->setWidget(2, QFormLayout::FieldRole, fullScreenBgColor);

        label_3 = new QLabel(tab);
        label_3->setObjectName(QStringLiteral("label_3"));

        formLayout->setWidget(3, QFormLayout::LabelRole, label_3);

        slideShowInterval = new QSpinBox(tab);
        slideShowInterval->setObjectName(QStringLiteral("slideShowInterval"));
        slideShowInterval->setMinimum(1);

        formLayout->setWidget(3, QFormLayout::FieldRole, slideShowInterval);

        tabWidget->addTab(tab, QString());

        verticalLayout->addWidget(tabWidget);

        buttonBox = new QDialogButtonBox(PreferencesDialog);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(PreferencesDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), PreferencesDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), PreferencesDialog, SLOT(reject()));

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(PreferencesDialog);
    } // setupUi

    void retranslateUi(QDialog *PreferencesDialog)
    {
        PreferencesDialog->setWindowTitle(QApplication::translate("PreferencesDialog", "Preferences", Q_NULLPTR));
        iconThemeLabel->setText(QApplication::translate("PreferencesDialog", "Icon theme:", Q_NULLPTR));
        label->setText(QApplication::translate("PreferencesDialog", "Normal background color:", Q_NULLPTR));
        label_2->setText(QApplication::translate("PreferencesDialog", "Fullscreen background color:", Q_NULLPTR));
        bgColor->setText(QString());
        fullScreenBgColor->setText(QString());
        label_3->setText(QApplication::translate("PreferencesDialog", "Slide show interval (seconds):", Q_NULLPTR));
        tabWidget->setTabText(tabWidget->indexOf(tab), QApplication::translate("PreferencesDialog", "General", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class PreferencesDialog: public Ui_PreferencesDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PREFERENCESDIALOG_H
