/********************************************************************************
** Form generated from reading UI file 'mainwindow.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MAINWINDOW_H
#define UI_MAINWINDOW_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QMainWindow>
#include <QtWidgets/QMenu>
#include <QtWidgets/QMenuBar>
#include <QtWidgets/QStatusBar>
#include <QtWidgets/QToolBar>
#include <QtWidgets/QWidget>
#include "imageview.h"

QT_BEGIN_NAMESPACE

class Ui_MainWindow
{
public:
    QAction *actionAbout;
    QAction *actionOpenFile;
    QAction *actionSave;
    QAction *actionSaveAs;
    QAction *actionClose;
    QAction *actionZoomIn;
    QAction *actionZoomOut;
    QAction *actionCopy;
    QAction *actionNext;
    QAction *actionPrevious;
    QAction *actionOriginalSize;
    QAction *actionZoomFit;
    QAction *actionRotateClockwise;
    QAction *actionRotateCounterclockwise;
    QAction *actionPreferences;
    QAction *actionPrint;
    QAction *actionFirst;
    QAction *actionLast;
    QAction *actionNewWindow;
    QAction *actionFlipHorizontal;
    QAction *actionScreenshot;
    QAction *actionFullScreen;
    QAction *actionFlipVertical;
    QAction *actionPaste;
    QAction *actionSlideShow;
    QAction *actionDelete;
    QAction *actionShowThumbnails;
    QAction *actionFileProperties;
    QAction *actionOpenDirectory;
    QAction *actionUpload;
    QWidget *centralWidget;
    QHBoxLayout *horizontalLayout;
    LxImage::ImageView *view;
    QMenuBar *menubar;
    QMenu *menu_File;
    QMenu *menu_Help;
    QMenu *menuGo;
    QMenu *menu_View;
    QMenu *menu_Edit;
    QToolBar *toolBar;
    QStatusBar *statusBar;

    void setupUi(QMainWindow *MainWindow)
    {
        if (MainWindow->objectName().isEmpty())
            MainWindow->setObjectName(QStringLiteral("MainWindow"));
        MainWindow->resize(543, 425);
        QIcon icon;
        QString iconThemeName = QStringLiteral("lximage-qt");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        MainWindow->setWindowIcon(icon);
        actionAbout = new QAction(MainWindow);
        actionAbout->setObjectName(QStringLiteral("actionAbout"));
        QIcon icon1;
        iconThemeName = QStringLiteral("help-about");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionAbout->setIcon(icon1);
        actionOpenFile = new QAction(MainWindow);
        actionOpenFile->setObjectName(QStringLiteral("actionOpenFile"));
        QIcon icon2;
        iconThemeName = QStringLiteral("document-open");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon2 = QIcon::fromTheme(iconThemeName);
        } else {
            icon2.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionOpenFile->setIcon(icon2);
        actionSave = new QAction(MainWindow);
        actionSave->setObjectName(QStringLiteral("actionSave"));
        QIcon icon3;
        iconThemeName = QStringLiteral("document-save");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon3 = QIcon::fromTheme(iconThemeName);
        } else {
            icon3.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionSave->setIcon(icon3);
        actionSaveAs = new QAction(MainWindow);
        actionSaveAs->setObjectName(QStringLiteral("actionSaveAs"));
        QIcon icon4;
        iconThemeName = QStringLiteral("document-save-as");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon4 = QIcon::fromTheme(iconThemeName);
        } else {
            icon4.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionSaveAs->setIcon(icon4);
        actionClose = new QAction(MainWindow);
        actionClose->setObjectName(QStringLiteral("actionClose"));
        QIcon icon5;
        iconThemeName = QStringLiteral("application-exit");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon5 = QIcon::fromTheme(iconThemeName);
        } else {
            icon5.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionClose->setIcon(icon5);
        actionZoomIn = new QAction(MainWindow);
        actionZoomIn->setObjectName(QStringLiteral("actionZoomIn"));
        QIcon icon6;
        iconThemeName = QStringLiteral("zoom-in");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon6 = QIcon::fromTheme(iconThemeName);
        } else {
            icon6.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionZoomIn->setIcon(icon6);
        actionZoomOut = new QAction(MainWindow);
        actionZoomOut->setObjectName(QStringLiteral("actionZoomOut"));
        QIcon icon7;
        iconThemeName = QStringLiteral("zoom-out");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon7 = QIcon::fromTheme(iconThemeName);
        } else {
            icon7.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionZoomOut->setIcon(icon7);
        actionCopy = new QAction(MainWindow);
        actionCopy->setObjectName(QStringLiteral("actionCopy"));
        QIcon icon8;
        iconThemeName = QStringLiteral("edit-copy");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon8 = QIcon::fromTheme(iconThemeName);
        } else {
            icon8.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionCopy->setIcon(icon8);
        actionNext = new QAction(MainWindow);
        actionNext->setObjectName(QStringLiteral("actionNext"));
        QIcon icon9;
        iconThemeName = QStringLiteral("go-next");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon9 = QIcon::fromTheme(iconThemeName);
        } else {
            icon9.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionNext->setIcon(icon9);
        actionPrevious = new QAction(MainWindow);
        actionPrevious->setObjectName(QStringLiteral("actionPrevious"));
        QIcon icon10;
        iconThemeName = QStringLiteral("go-previous");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon10 = QIcon::fromTheme(iconThemeName);
        } else {
            icon10.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionPrevious->setIcon(icon10);
        actionOriginalSize = new QAction(MainWindow);
        actionOriginalSize->setObjectName(QStringLiteral("actionOriginalSize"));
        QIcon icon11;
        iconThemeName = QStringLiteral("zoom-original");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon11 = QIcon::fromTheme(iconThemeName);
        } else {
            icon11.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionOriginalSize->setIcon(icon11);
        actionZoomFit = new QAction(MainWindow);
        actionZoomFit->setObjectName(QStringLiteral("actionZoomFit"));
        QIcon icon12;
        iconThemeName = QStringLiteral("zoom-fit-best");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon12 = QIcon::fromTheme(iconThemeName);
        } else {
            icon12.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionZoomFit->setIcon(icon12);
        actionRotateClockwise = new QAction(MainWindow);
        actionRotateClockwise->setObjectName(QStringLiteral("actionRotateClockwise"));
        QIcon icon13;
        iconThemeName = QStringLiteral("object-rotate-right");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon13 = QIcon::fromTheme(iconThemeName);
        } else {
            icon13.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionRotateClockwise->setIcon(icon13);
        actionRotateCounterclockwise = new QAction(MainWindow);
        actionRotateCounterclockwise->setObjectName(QStringLiteral("actionRotateCounterclockwise"));
        QIcon icon14;
        iconThemeName = QStringLiteral("object-rotate-left");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon14 = QIcon::fromTheme(iconThemeName);
        } else {
            icon14.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionRotateCounterclockwise->setIcon(icon14);
        actionPreferences = new QAction(MainWindow);
        actionPreferences->setObjectName(QStringLiteral("actionPreferences"));
        actionPrint = new QAction(MainWindow);
        actionPrint->setObjectName(QStringLiteral("actionPrint"));
        actionFirst = new QAction(MainWindow);
        actionFirst->setObjectName(QStringLiteral("actionFirst"));
        QIcon icon15;
        iconThemeName = QStringLiteral("go-first");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon15 = QIcon::fromTheme(iconThemeName);
        } else {
            icon15.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionFirst->setIcon(icon15);
        actionLast = new QAction(MainWindow);
        actionLast->setObjectName(QStringLiteral("actionLast"));
        QIcon icon16;
        iconThemeName = QStringLiteral("go-last");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon16 = QIcon::fromTheme(iconThemeName);
        } else {
            icon16.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionLast->setIcon(icon16);
        actionNewWindow = new QAction(MainWindow);
        actionNewWindow->setObjectName(QStringLiteral("actionNewWindow"));
        QIcon icon17;
        iconThemeName = QStringLiteral("document-new");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon17 = QIcon::fromTheme(iconThemeName);
        } else {
            icon17.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionNewWindow->setIcon(icon17);
        actionFlipHorizontal = new QAction(MainWindow);
        actionFlipHorizontal->setObjectName(QStringLiteral("actionFlipHorizontal"));
        actionScreenshot = new QAction(MainWindow);
        actionScreenshot->setObjectName(QStringLiteral("actionScreenshot"));
        QIcon icon18;
        iconThemeName = QStringLiteral("camera-photo");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon18 = QIcon::fromTheme(iconThemeName);
        } else {
            icon18.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionScreenshot->setIcon(icon18);
        actionFullScreen = new QAction(MainWindow);
        actionFullScreen->setObjectName(QStringLiteral("actionFullScreen"));
        actionFullScreen->setCheckable(true);
        actionFlipVertical = new QAction(MainWindow);
        actionFlipVertical->setObjectName(QStringLiteral("actionFlipVertical"));
        actionPaste = new QAction(MainWindow);
        actionPaste->setObjectName(QStringLiteral("actionPaste"));
        QIcon icon19;
        iconThemeName = QStringLiteral("edit-paste");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon19 = QIcon::fromTheme(iconThemeName);
        } else {
            icon19.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionPaste->setIcon(icon19);
        actionSlideShow = new QAction(MainWindow);
        actionSlideShow->setObjectName(QStringLiteral("actionSlideShow"));
        actionSlideShow->setCheckable(true);
        QIcon icon20;
        iconThemeName = QStringLiteral("media-playback-start");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon20 = QIcon::fromTheme(iconThemeName);
        } else {
            icon20.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionSlideShow->setIcon(icon20);
        actionDelete = new QAction(MainWindow);
        actionDelete->setObjectName(QStringLiteral("actionDelete"));
        QIcon icon21;
        iconThemeName = QStringLiteral("edit-delete");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon21 = QIcon::fromTheme(iconThemeName);
        } else {
            icon21.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionDelete->setIcon(icon21);
        actionShowThumbnails = new QAction(MainWindow);
        actionShowThumbnails->setObjectName(QStringLiteral("actionShowThumbnails"));
        actionShowThumbnails->setCheckable(true);
        actionFileProperties = new QAction(MainWindow);
        actionFileProperties->setObjectName(QStringLiteral("actionFileProperties"));
        actionOpenDirectory = new QAction(MainWindow);
        actionOpenDirectory->setObjectName(QStringLiteral("actionOpenDirectory"));
        actionOpenDirectory->setIcon(icon2);
        actionUpload = new QAction(MainWindow);
        actionUpload->setObjectName(QStringLiteral("actionUpload"));
        QIcon icon22(QIcon::fromTheme(QStringLiteral("upload-media")));
        actionUpload->setIcon(icon22);
        centralWidget = new QWidget(MainWindow);
        centralWidget->setObjectName(QStringLiteral("centralWidget"));
        horizontalLayout = new QHBoxLayout(centralWidget);
        horizontalLayout->setSpacing(0);
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        view = new LxImage::ImageView(centralWidget);
        view->setObjectName(QStringLiteral("view"));
        view->setRenderHints(QPainter::Antialiasing|QPainter::HighQualityAntialiasing|QPainter::TextAntialiasing);
        view->setDragMode(QGraphicsView::ScrollHandDrag);
        view->setTransformationAnchor(QGraphicsView::AnchorUnderMouse);

        horizontalLayout->addWidget(view);

        MainWindow->setCentralWidget(centralWidget);
        menubar = new QMenuBar(MainWindow);
        menubar->setObjectName(QStringLiteral("menubar"));
        menubar->setGeometry(QRect(0, 0, 543, 23));
        menu_File = new QMenu(menubar);
        menu_File->setObjectName(QStringLiteral("menu_File"));
        menu_Help = new QMenu(menubar);
        menu_Help->setObjectName(QStringLiteral("menu_Help"));
        menuGo = new QMenu(menubar);
        menuGo->setObjectName(QStringLiteral("menuGo"));
        menu_View = new QMenu(menubar);
        menu_View->setObjectName(QStringLiteral("menu_View"));
        menu_Edit = new QMenu(menubar);
        menu_Edit->setObjectName(QStringLiteral("menu_Edit"));
        MainWindow->setMenuBar(menubar);
        toolBar = new QToolBar(MainWindow);
        toolBar->setObjectName(QStringLiteral("toolBar"));
        toolBar->setToolButtonStyle(Qt::ToolButtonIconOnly);
        toolBar->setFloatable(false);
        MainWindow->addToolBar(Qt::TopToolBarArea, toolBar);
        statusBar = new QStatusBar(MainWindow);
        statusBar->setObjectName(QStringLiteral("statusBar"));
        MainWindow->setStatusBar(statusBar);

        menubar->addAction(menu_File->menuAction());
        menubar->addAction(menu_Edit->menuAction());
        menubar->addAction(menu_View->menuAction());
        menubar->addAction(menuGo->menuAction());
        menubar->addAction(menu_Help->menuAction());
        menu_File->addAction(actionNewWindow);
        menu_File->addAction(actionOpenFile);
        menu_File->addAction(actionOpenDirectory);
        menu_File->addAction(actionScreenshot);
        menu_File->addAction(actionSave);
        menu_File->addAction(actionSaveAs);
        menu_File->addAction(actionDelete);
        menu_File->addSeparator();
        menu_File->addAction(actionFileProperties);
        menu_File->addAction(actionPrint);
        menu_File->addSeparator();
        menu_File->addAction(actionClose);
        menu_Help->addAction(actionAbout);
        menuGo->addAction(actionPrevious);
        menuGo->addAction(actionNext);
        menuGo->addAction(actionFirst);
        menuGo->addAction(actionLast);
        menu_View->addAction(actionZoomIn);
        menu_View->addAction(actionZoomOut);
        menu_View->addAction(actionOriginalSize);
        menu_View->addAction(actionZoomFit);
        menu_View->addSeparator();
        menu_View->addAction(actionShowThumbnails);
        menu_View->addSeparator();
        menu_View->addAction(actionFullScreen);
        menu_View->addAction(actionSlideShow);
        menu_Edit->addAction(actionRotateClockwise);
        menu_Edit->addAction(actionRotateCounterclockwise);
        menu_Edit->addAction(actionFlipHorizontal);
        menu_Edit->addAction(actionFlipVertical);
        menu_Edit->addSeparator();
        menu_Edit->addAction(actionCopy);
        menu_Edit->addAction(actionPaste);
        menu_Edit->addSeparator();
        menu_Edit->addAction(actionUpload);
        menu_Edit->addSeparator();
        menu_Edit->addAction(actionPreferences);
        toolBar->addAction(actionPrevious);
        toolBar->addAction(actionNext);
        toolBar->addSeparator();
        toolBar->addAction(actionOpenFile);
        toolBar->addAction(actionSaveAs);
        toolBar->addAction(actionCopy);
        toolBar->addAction(actionPaste);
        toolBar->addSeparator();
        toolBar->addAction(actionRotateClockwise);
        toolBar->addAction(actionRotateCounterclockwise);
        toolBar->addAction(actionZoomIn);
        toolBar->addAction(actionZoomOut);
        toolBar->addAction(actionZoomFit);
        toolBar->addAction(actionOriginalSize);
        toolBar->addSeparator();
        toolBar->addAction(actionSlideShow);

        retranslateUi(MainWindow);

        QMetaObject::connectSlotsByName(MainWindow);
    } // setupUi

    void retranslateUi(QMainWindow *MainWindow)
    {
        MainWindow->setWindowTitle(QApplication::translate("MainWindow", "Image Viewer", Q_NULLPTR));
        actionAbout->setText(QApplication::translate("MainWindow", "&About", Q_NULLPTR));
        actionOpenFile->setText(QApplication::translate("MainWindow", "&Open File", Q_NULLPTR));
#ifndef QT_NO_SHORTCUT
        actionOpenFile->setShortcut(QApplication::translate("MainWindow", "Ctrl+O", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        actionSave->setText(QApplication::translate("MainWindow", "&Save", Q_NULLPTR));
#ifndef QT_NO_SHORTCUT
        actionSave->setShortcut(QApplication::translate("MainWindow", "Ctrl+S", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        actionSaveAs->setText(QApplication::translate("MainWindow", "Save &As", Q_NULLPTR));
#ifndef QT_NO_SHORTCUT
        actionSaveAs->setShortcut(QApplication::translate("MainWindow", "Ctrl+A", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        actionClose->setText(QApplication::translate("MainWindow", "&Close", Q_NULLPTR));
#ifndef QT_NO_SHORTCUT
        actionClose->setShortcut(QApplication::translate("MainWindow", "Ctrl+W", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        actionZoomIn->setText(QApplication::translate("MainWindow", "Zoom &In", Q_NULLPTR));
#ifndef QT_NO_SHORTCUT
        actionZoomIn->setShortcut(QApplication::translate("MainWindow", "Ctrl+=", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        actionZoomOut->setText(QApplication::translate("MainWindow", "Zoom &Out", Q_NULLPTR));
#ifndef QT_NO_SHORTCUT
        actionZoomOut->setShortcut(QApplication::translate("MainWindow", "Ctrl+-", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        actionCopy->setText(QApplication::translate("MainWindow", "&Copy to Clipboard", Q_NULLPTR));
        actionNext->setText(QApplication::translate("MainWindow", "Next File", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        actionNext->setToolTip(QApplication::translate("MainWindow", "Next File", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_SHORTCUT
        actionNext->setShortcut(QApplication::translate("MainWindow", "PgDown", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        actionPrevious->setText(QApplication::translate("MainWindow", "Previous File", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        actionPrevious->setToolTip(QApplication::translate("MainWindow", "Previous File", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_SHORTCUT
        actionPrevious->setShortcut(QApplication::translate("MainWindow", "PgUp", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        actionOriginalSize->setText(QApplication::translate("MainWindow", "Original Size", Q_NULLPTR));
#ifndef QT_NO_SHORTCUT
        actionOriginalSize->setShortcut(QApplication::translate("MainWindow", "Ctrl+0", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        actionZoomFit->setText(QApplication::translate("MainWindow", "&Fit", Q_NULLPTR));
        actionRotateClockwise->setText(QApplication::translate("MainWindow", "&Rotate Clockwise", Q_NULLPTR));
        actionRotateCounterclockwise->setText(QApplication::translate("MainWindow", "Rotate &Counterclockwise", Q_NULLPTR));
        actionPreferences->setText(QApplication::translate("MainWindow", "P&references", Q_NULLPTR));
        actionPrint->setText(QApplication::translate("MainWindow", "&Print", Q_NULLPTR));
#ifndef QT_NO_SHORTCUT
        actionPrint->setShortcut(QApplication::translate("MainWindow", "Ctrl+P", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        actionFirst->setText(QApplication::translate("MainWindow", "First File", Q_NULLPTR));
#ifndef QT_NO_SHORTCUT
        actionFirst->setShortcut(QApplication::translate("MainWindow", "Home", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        actionLast->setText(QApplication::translate("MainWindow", "Last File", Q_NULLPTR));
#ifndef QT_NO_SHORTCUT
        actionLast->setShortcut(QApplication::translate("MainWindow", "End", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        actionNewWindow->setText(QApplication::translate("MainWindow", "&New Window", Q_NULLPTR));
#ifndef QT_NO_SHORTCUT
        actionNewWindow->setShortcut(QApplication::translate("MainWindow", "Ctrl+N", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        actionFlipHorizontal->setText(QApplication::translate("MainWindow", "Flip &Horizontally", Q_NULLPTR));
        actionScreenshot->setText(QApplication::translate("MainWindow", "Capture Screenshot", Q_NULLPTR));
        actionFullScreen->setText(QApplication::translate("MainWindow", "F&ull Screen", Q_NULLPTR));
#ifndef QT_NO_SHORTCUT
        actionFullScreen->setShortcut(QApplication::translate("MainWindow", "F11", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        actionFlipVertical->setText(QApplication::translate("MainWindow", "Flip &Vertically", Q_NULLPTR));
        actionPaste->setText(QApplication::translate("MainWindow", "&Paste from Clipboard", Q_NULLPTR));
        actionSlideShow->setText(QApplication::translate("MainWindow", "&Slide Show", Q_NULLPTR));
        actionDelete->setText(QApplication::translate("MainWindow", "&Delete", Q_NULLPTR));
#ifndef QT_NO_SHORTCUT
        actionDelete->setShortcut(QApplication::translate("MainWindow", "Del", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        actionShowThumbnails->setText(QApplication::translate("MainWindow", "Show Thumbnails", Q_NULLPTR));
        actionFileProperties->setText(QApplication::translate("MainWindow", "File Properties", Q_NULLPTR));
        actionOpenDirectory->setText(QApplication::translate("MainWindow", "Open &Directory", Q_NULLPTR));
#ifndef QT_NO_SHORTCUT
        actionOpenDirectory->setShortcut(QApplication::translate("MainWindow", "Ctrl+D", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        actionUpload->setText(QApplication::translate("MainWindow", "Upload", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        actionUpload->setToolTip(QApplication::translate("MainWindow", "Upload the image", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        menu_File->setTitle(QApplication::translate("MainWindow", "&File", Q_NULLPTR));
        menu_Help->setTitle(QApplication::translate("MainWindow", "&Help", Q_NULLPTR));
        menuGo->setTitle(QApplication::translate("MainWindow", "Go", Q_NULLPTR));
        menu_View->setTitle(QApplication::translate("MainWindow", "&View", Q_NULLPTR));
        menu_Edit->setTitle(QApplication::translate("MainWindow", "&Edit", Q_NULLPTR));
        toolBar->setWindowTitle(QApplication::translate("MainWindow", "Toolbar", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class MainWindow: public Ui_MainWindow {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MAINWINDOW_H
