/********************************************************************************
** Form generated from reading UI file 'uploaddialog.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_UPLOADDIALOG_H
#define UI_UPLOADDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_UploadDialog
{
public:
    QVBoxLayout *verticalLayout;
    QComboBox *providerComboBox;
    QProgressBar *progressBar;
    QHBoxLayout *horizontalLayout_2;
    QLineEdit *linkLineEdit;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *actionButton;

    void setupUi(QDialog *UploadDialog)
    {
        if (UploadDialog->objectName().isEmpty())
            UploadDialog->setObjectName(QStringLiteral("UploadDialog"));
        UploadDialog->resize(300, 100);
        verticalLayout = new QVBoxLayout(UploadDialog);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        providerComboBox = new QComboBox(UploadDialog);
        providerComboBox->setObjectName(QStringLiteral("providerComboBox"));

        verticalLayout->addWidget(providerComboBox);

        progressBar = new QProgressBar(UploadDialog);
        progressBar->setObjectName(QStringLiteral("progressBar"));
        progressBar->setEnabled(true);

        verticalLayout->addWidget(progressBar);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        linkLineEdit = new QLineEdit(UploadDialog);
        linkLineEdit->setObjectName(QStringLiteral("linkLineEdit"));
        linkLineEdit->setReadOnly(true);

        horizontalLayout_2->addWidget(linkLineEdit);


        verticalLayout->addLayout(horizontalLayout_2);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        actionButton = new QPushButton(UploadDialog);
        actionButton->setObjectName(QStringLiteral("actionButton"));

        horizontalLayout->addWidget(actionButton);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(UploadDialog);

        QMetaObject::connectSlotsByName(UploadDialog);
    } // setupUi

    void retranslateUi(QDialog *UploadDialog)
    {
        UploadDialog->setWindowTitle(QApplication::translate("UploadDialog", "Upload", Q_NULLPTR));
        actionButton->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class UploadDialog: public Ui_UploadDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_UPLOADDIALOG_H
