/********************************************************************************
** Form generated from reading UI file 'screenshotdialog.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SCREENSHOTDIALOG_H
#define UI_SCREENSHOTDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_ScreenshotDialog
{
public:
    QFormLayout *formLayout;
    QLabel *label;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QRadioButton *wholeScreen;
    QRadioButton *currentWindow;
    QRadioButton *screenArea;
    QCheckBox *includeCursor;
    QSpinBox *delay;
    QDialogButtonBox *buttonBox;
    QLabel *label_2;
    QCheckBox *includeFrame;

    void setupUi(QDialog *ScreenshotDialog)
    {
        if (ScreenshotDialog->objectName().isEmpty())
            ScreenshotDialog->setObjectName(QStringLiteral("ScreenshotDialog"));
        ScreenshotDialog->resize(348, 261);
        QIcon icon;
        QString iconThemeName = QStringLiteral("camera-photo");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QStringLiteral("."), QSize(), QIcon::Normal, QIcon::Off);
        }
        ScreenshotDialog->setWindowIcon(icon);
        formLayout = new QFormLayout(ScreenshotDialog);
        formLayout->setObjectName(QStringLiteral("formLayout"));
        formLayout->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        label = new QLabel(ScreenshotDialog);
        label->setObjectName(QStringLiteral("label"));

        formLayout->setWidget(0, QFormLayout::SpanningRole, label);

        groupBox = new QGroupBox(ScreenshotDialog);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        wholeScreen = new QRadioButton(groupBox);
        wholeScreen->setObjectName(QStringLiteral("wholeScreen"));
        wholeScreen->setChecked(true);

        verticalLayout->addWidget(wholeScreen);

        currentWindow = new QRadioButton(groupBox);
        currentWindow->setObjectName(QStringLiteral("currentWindow"));

        verticalLayout->addWidget(currentWindow);

        screenArea = new QRadioButton(groupBox);
        screenArea->setObjectName(QStringLiteral("screenArea"));

        verticalLayout->addWidget(screenArea);


        formLayout->setWidget(1, QFormLayout::SpanningRole, groupBox);

        includeCursor = new QCheckBox(ScreenshotDialog);
        includeCursor->setObjectName(QStringLiteral("includeCursor"));

        formLayout->setWidget(3, QFormLayout::SpanningRole, includeCursor);

        delay = new QSpinBox(ScreenshotDialog);
        delay->setObjectName(QStringLiteral("delay"));

        formLayout->setWidget(5, QFormLayout::FieldRole, delay);

        buttonBox = new QDialogButtonBox(ScreenshotDialog);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        formLayout->setWidget(6, QFormLayout::SpanningRole, buttonBox);

        label_2 = new QLabel(ScreenshotDialog);
        label_2->setObjectName(QStringLiteral("label_2"));

        formLayout->setWidget(5, QFormLayout::LabelRole, label_2);

        includeFrame = new QCheckBox(ScreenshotDialog);
        includeFrame->setObjectName(QStringLiteral("includeFrame"));
        includeFrame->setEnabled(false);
        includeFrame->setChecked(true);

        formLayout->setWidget(2, QFormLayout::LabelRole, includeFrame);


        retranslateUi(ScreenshotDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), ScreenshotDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), ScreenshotDialog, SLOT(reject()));
        QObject::connect(currentWindow, SIGNAL(toggled(bool)), includeFrame, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(ScreenshotDialog);
    } // setupUi

    void retranslateUi(QDialog *ScreenshotDialog)
    {
        ScreenshotDialog->setWindowTitle(QApplication::translate("ScreenshotDialog", "Screenshot", Q_NULLPTR));
        label->setText(QApplication::translate("ScreenshotDialog", "Take a screenshot", Q_NULLPTR));
        groupBox->setTitle(QApplication::translate("ScreenshotDialog", "Region", Q_NULLPTR));
        wholeScreen->setText(QApplication::translate("ScreenshotDialog", "Whole screen", Q_NULLPTR));
        currentWindow->setText(QApplication::translate("ScreenshotDialog", "Current window only", Q_NULLPTR));
        screenArea->setText(QApplication::translate("ScreenshotDialog", "Capture an area of the screen", Q_NULLPTR));
        includeCursor->setText(QApplication::translate("ScreenshotDialog", "Include mouse cursor", Q_NULLPTR));
        delay->setSuffix(QApplication::translate("ScreenshotDialog", " seconds", Q_NULLPTR));
        label_2->setText(QApplication::translate("ScreenshotDialog", "Delay:", Q_NULLPTR));
        includeFrame->setText(QApplication::translate("ScreenshotDialog", "Include window title and frame", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class ScreenshotDialog: public Ui_ScreenshotDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SCREENSHOTDIALOG_H
